/* 
 * Copyright (c) 2012, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.client.rest;

import java.util.Properties;

import org.ogf.graap.wsag.api.exceptions.ResourceUnavailableException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnknownException;
import org.ogf.graap.wsag.api.rest.RestAcceptanceEndpoint;
import org.ogf.graap.wsag.api.security.ISecurityProperties;
import org.ogf.graap.wsag.client.api.AgreementAcceptanceClient;
import org.ogf.schemas.graap.wsAgreement.AcceptAgreementInputDocument;
import org.ogf.schemas.graap.wsAgreement.RejectAgreementInputDocument;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

/**
 * @author owaeld
 * 
 */
public class RestAgreementAcceptanceClient
    implements AgreementAcceptanceClient
{

    private final RestRemoteClient<RestAcceptanceEndpoint> client;

    /**
     * default constructor
     */
    public RestAgreementAcceptanceClient( EndpointReferenceType epr, ISecurityProperties securityProperties )
    {
        client =
            RestRemoteClient.getInstance( epr, new Properties(), securityProperties,
                RestAcceptanceEndpoint.class );
    }

    /**
     * @see org.ogf.graap.wsag.client.api.AgreementAcceptanceClient#accept()
     */
    @Override
    public void accept() throws ResourceUnknownException, ResourceUnavailableException
    {
        AcceptAgreementInputDocument input = AcceptAgreementInputDocument.Factory.newInstance();
        input.addNewAcceptAgreementInput();

        client.getApplicationClient().accept( input );
    }

    /**
     * @see org.ogf.graap.wsag.client.api.AgreementAcceptanceClient#reject()
     */
    @Override
    public void reject() throws ResourceUnknownException, ResourceUnavailableException
    {
        RejectAgreementInputDocument input = RejectAgreementInputDocument.Factory.newInstance();
        input.addNewRejectAgreementInput();

        client.getApplicationClient().reject( input );
    }

    /**
     * @see org.ogf.graap.wsag.client.api.AgreementAcceptanceClient#destroy()
     */
    @Override
    public void destroy() throws ResourceUnknownException, ResourceUnavailableException
    {
        client.getApplicationClient().destroy();
    }

}
