/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.client.rest;

import java.net.URI;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;
import java.util.Vector;

import org.ogf.graap.wsag.api.exceptions.ResourceUnavailableException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnknownException;
import org.ogf.graap.wsag.api.rest.RestAgreementFactoryRegistry;
import org.ogf.graap.wsag.api.security.ISecurityProperties;
import org.ogf.graap.wsag.client.api.AgreementFactoryClient;
import org.ogf.graap.wsag.client.api.AgreementFactoryRegistryClient;
import org.ogf.graap.wsag.client.api.RemoteClient;
import org.ogf.graap.wsag.client.api.impl.AbstractFactoryRegistryClient;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

/**
 * Default implementation of an agreement factory client.
 * 
 * @author Oliver Waeldrich
 * 
 */
public class RestAgreementFactoryRegistryClient extends AbstractFactoryRegistryClient
    implements AgreementFactoryRegistryClient
{

    private final RestRemoteClient<RestAgreementFactoryRegistry> client;

    /**
     * Instantiates a new agreement factory client for the given endpoint reference.
     * 
     * @param epr
     *            the agreement factory EPR
     * @param properties
     *            the client properties
     * @param securityProperties
     *            the security properties
     */
    public RestAgreementFactoryRegistryClient( EndpointReferenceType epr, Properties properties,
                                               ISecurityProperties securityProperties )
    {
        client =
            RestRemoteClient.getInstance( epr, properties, securityProperties,
                RestAgreementFactoryRegistry.class );
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public AgreementFactoryClient[] listAgreementFactories()
        throws ResourceUnknownException, ResourceUnavailableException
    {
        List<URI> agreementURIs = client.getApplicationClient().listFactoryReferences();
        List<AgreementFactoryClient> result = new Vector<AgreementFactoryClient>();

        for ( Iterator<URI> iterator = agreementURIs.iterator(); iterator.hasNext(); )
        {
            URI uri = iterator.next();
            EndpointReferenceType epr = EndpointReferenceType.Factory.newInstance();
            epr.addNewAddress().setStringValue( uri.toASCIIString() );
            result.add( new RestAgreementFactoryClient( epr, getProperties(), getSecurityProperties() ) );
        }
        return result.toArray( new AgreementFactoryClient[result.size()] );
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ogf.graap.wsag.client.api.impl.AbstractClient#getRemoteClient()
     */
    @Override
    public RemoteClient getRemoteClient()
    {
        return client;
    }

}
